<template>
  <div class="card horizontal-card h-100 shadow-sm">
    <div class="card-body p-0">
      <div class="row h-100">
        <div class="col-7 my-2">
          <div
              class="px-3 h-100 d-flex align-items-start justify-content-start flex-column"
              :class="[{'text-end': isRTL},{'text-start': !isRTL}]"
          >
            <h5 class="card-title font-size-14">{{ data?.title }}</h5>
            <div class="mt-auto">
              <p class="card-text text-muted mb-1 font-size-14">
                <template v-if="data.price == 0">
                  {{ t('advertise.agreed') }}
                </template>
                <template v-else>
                  <template v-if="data.price !== '' && data.price !== null">
                    <span class="fw-bold" :class="isRTL ? 'ms-1' : 'me-1'">
                      {{ $helper?.getCurrency(data.price) }}
                    </span>
                    <span class="font-size-10">{{ $t('reservations.currency') }}</span>
                  </template>
                </template>
              </p>
            </div>
          </div>
        </div>
        <div class="col-5 my-2">
          <button class="btn btn-default p-1 px-2 mx-2 my-1" @click="createChat">
            <i class="icon icon-regular-chat-dots"></i>
          </button>
          <button class="btn btn-danger p-1 px-2 mx-2 my-1" @click="removeRequest">
            <i class="icon icon-regular-trash text-white"></i>
          </button>
        </div>
        <div class="col-12 my-2 px-4">
          <small class="text-muted font-size-10">
            {{ data.date }} | {{ data.province?.title }}, {{ data.city?.title }}, {{ data.zone?.title }}
          </small>
        </div>
      </div>
    </div>
  </div>
</template>

<script setup>
import { useI18n } from 'vue-i18n'
import { ref, reactive, onMounted, onBeforeUnmount, computed } from 'vue'
import {useRouter} from "vue-router";

const { locale, t } = useI18n()
const { $helper,$api,$sweetalert } = useNuxtApp()

const router = useRouter();

const props = defineProps({
  data: {
    type: Object,
    required: true
  },
  click: {
    type: Boolean,
    default: true
  },
  step: {
    type: Boolean,
    default: false
  }
})

const emit = defineEmits(['resetData']);

const isRTL = computed(() => ['fa', 'ar'].includes(locale.value))

// وضعیت لودینگ کلی
const meta = reactive({
  loaded: false
})

onMounted(() => {
  setTimeout(() => {
    meta.loaded = true
  }, 100)
})

// Lazy Loading برای تصویر بک‌گراند
const imageRef = ref(null)
const loadedImage = ref(false)
let observer = null

onMounted(() => {
  observer = new IntersectionObserver(
      ([entry]) => {
        if (entry.isIntersecting) {
          loadedImage.value = true
          observer.disconnect()
        }
      },
      {
        root: null,
        threshold: 0.1
      }
  )

  if (imageRef.value) {
    observer.observe(imageRef.value)
  }
})

onBeforeUnmount(() => {
  if (observer) {
    observer.disconnect()
  }
})

const createChat = async () => {
  await $api.post('/user/chat/customer', {
    advertise_id: props.data.advertise_id,
    user_id: props.data.user_id,
  }).then((value) => {
    if (value.data.status) {
      router.push(`/chat?id=${value.data.data.chat_id}`)
    } else {
      $sweetalert.error(value.data.data.error || 'خطا در ایجاد گفتگو.')
    }
  })
}

const removeRequest = async () => {
  await $sweetalert.confirm(async () => {
    await $api.post('/user/request/delete', {
      id: props.data.id
    }).then((value) => {
      if (value.data.status) {
        $sweetalert.success('مشتری با موفقیت حذف شد');
        emit('resetData');
      }
    })
  })
}

</script>

<style scoped>
.bg-cover {
  background-size: cover;
}
.bg-center {
  background-position: center;
}
.lazy-placeholder {
  background-color: #eee;
}
</style>